summaryrefslogtreecommitdiff
path: root/include/arch
diff options
context:
space:
mode:
authorIvan Zhakov <ivan@apache.org>2019-06-07 10:22:43 +0000
committerIvan Zhakov <ivan@apache.org>2019-06-07 10:22:43 +0000
commit3278e5ffdd736268b1abd926d3b070ff19ed5d2a (patch)
tree4d0e1981d75084061978158a36a14fcbf2edb5ac /include/arch
parent44faed2a69fdfd531319ad8928137406a403ab31 (diff)
downloadapr-3278e5ffdd736268b1abd926d3b070ff19ed5d2a.tar.gz
Windows platform: Use semaphore object instead of manual reset event to
implement timed unnested apr_thread_mutex_t. git-svn-id: https://svn.apache.org/repos/asf/apr/apr/trunk@1860744 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/arch')
-rw-r--r--include/arch/win32/apr_arch_thread_mutex.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/arch/win32/apr_arch_thread_mutex.h b/include/arch/win32/apr_arch_thread_mutex.h
index 13d3c1cbd..b6d0384a5 100644
--- a/include/arch/win32/apr_arch_thread_mutex.h
+++ b/include/arch/win32/apr_arch_thread_mutex.h
@@ -21,11 +21,11 @@
typedef enum thread_mutex_type {
thread_mutex_critical_section,
- thread_mutex_unnested_event,
+ thread_mutex_unnested_semaphore,
thread_mutex_nested_mutex
} thread_mutex_type;
/* handle applies only to unnested_event on all platforms
* and nested_mutex on Win9x only. Otherwise critical_section
* is used for NT nexted mutexes providing optimal performance.
*/
@@ -21,11 +21,11 @@
thread_mutex_nested_mutex
} thread_mutex_type;
-/* handle applies only to unnested_event on all platforms
+/* handle applies only to unnested_semaphore on all platforms
* and nested_mutex on Win9x only. Otherwise critical_section
* is used for NT nexted mutexes providing optimal performance.